unit PageDlg;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Module1;

type
  TfrmPageDlg = class(TForm)
    GroupBox1: TGroupBox;
    cboPaperSize: TComboBox;
    Label1: TLabel;
    Label2: TLabel;
    txtPaperWidth: TEdit;
    txtPaperHeight: TEdit;
    GroupBox2: TGroupBox;
    Label3: TLabel;
    txtTopMargin: TEdit;
    txtLeftMargin: TEdit;
    txtRightMargin: TEdit;
    txtBottomMargin: TEdit;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    cmdOK: TButton;
    Button2: TButton;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure cboPaperSizeClick(Sender: TObject);
    procedure txtPaperWidthChange(Sender: TObject);
    procedure txtPaperHeightChange(Sender: TObject);
    procedure txtTopMarginChange(Sender: TObject);
    procedure txtLeftMarginChange(Sender: TObject);
    procedure txtRightMarginChange(Sender: TObject);
    procedure txtBottomMarginChange(Sender: TObject);
    procedure cmdOKClick(Sender: TObject);
    procedure Button2Click(Sender: TObject);
  private
    Function PageSettingsValid:boolean;
  public

  end;

var
  frmPageDlg: TfrmPageDlg;

implementation

uses TXglobal, main;

{$R *.DFM}

procedure TfrmPageDlg.FormCreate(Sender: TObject);
begin
   // Fill Page Size combo box
   cboPaperSize.Items.Add(A4);
   cboPaperSize.Items.Add(A5);
   cboPaperSize.Items.Add(B5);
   cboPaperSize.Items.Add(LETTER);
   cboPaperSize.Items.Add(LEGAL);
   cboPaperSize.Items.Add(USER_DEFINED);
end;

procedure TfrmPageDlg.FormShow(Sender: TObject);
begin
        // Copy document size and margins to dialog controls
        txtLeftMargin.Text := Twips2DlgString(doc.lLeftMargin);
        txtTopMargin.Text := Twips2DlgString(doc.lTopMargin);
        txtRightMargin.Text := Twips2DlgString(doc.lRightMargin);
        txtBottomMargin.Text := Twips2DlgString(doc.lBottomMargin);
        txtPaperWidth.Text := Twips2DlgString(doc.lWidth);
        txtPaperHeight.Text := Twips2DlgString(doc.lHeight);
        // Select size in combo box
        // cboPaperSize.ItemIndex := Doc.nPaperSize;
end;

Function TfrmPageDlg.PageSettingsValid() : boolean;
{ Check if page size and margin settings are valid. Restrict
  page size to avoid overflow in scrollbar range.}
var l : LongInt;
    bValid : boolean;
begin
  bValid := True;

  l := DlgString2Twips(txtLeftMargin.Text);
  If (l > DlgString2Twips(txtPaperWidth.Text)) Or (l < 0) Then bValid := False;

  l := DlgString2Twips(txtRightMargin.Text);
  If (l > DlgString2Twips(txtPaperWidth.Text)) Or (l < 0) Then bValid := False;

  l := DlgString2Twips(txtTopMargin.Text);
  If (l > DlgString2Twips(txtPaperHeight.Text)) Or (l < 0) Then bValid := False;

  l := DlgString2Twips(txtBottomMargin.Text);
  If (l > DlgString2Twips(txtPaperHeight.Text)) Or (l < 0) Then bValid := False;

  l := DlgString2Twips(txtPaperWidth.Text);
  If (2 * l > MAXINT) Or (l <= 0) Then bValid := False;

  l := DlgString2Twips(txtPaperHeight.Text);
  If (l > MAXINT) Or (l <= 0) Then bValid := False;

  PageSettingsValid := bValid;
End;


procedure TfrmPageDlg.cboPaperSizeClick(Sender: TObject);
begin
  Case cboPaperSize.ItemIndex of
     0  : begin     // A4
            txtPaperWidth.Text := Twips2DlgString(DINA4_X);
            txtPaperHeight.Text := Twips2DlgString(DINA4_Y);
          end;
     1  : begin     // A5
            txtPaperWidth.Text := Twips2DlgString(DINA5_X);
            txtPaperHeight.Text := Twips2DlgString(DINA5_Y);
          end;
     2  : begin     // B5
            txtPaperWidth.Text := Twips2DlgString(B5_X);
            txtPaperHeight.Text := Twips2DlgString(B5_Y);
          end;
     3  : begin     // LETTER
            txtPaperWidth.Text := Twips2DlgString(USLET_X);
            txtPaperHeight.Text := Twips2DlgString(USLET_Y);
          end;
     4  : begin     // LEGAL
            txtPaperWidth.Text := Twips2DlgString(USLEGAL_X);
            txtPaperHeight.Text := Twips2DlgString(USLEGAL_Y);
          end;
  End; // case
end;

procedure TfrmPageDlg.txtPaperWidthChange(Sender: TObject);
begin
  cmdOk.Enabled := PageSettingsValid();
end;

procedure TfrmPageDlg.txtPaperHeightChange(Sender: TObject);
begin
  cmdOk.Enabled := PageSettingsValid();
end;

procedure TfrmPageDlg.txtTopMarginChange(Sender: TObject);
begin
  cmdOk.Enabled := PageSettingsValid();
end;

procedure TfrmPageDlg.txtLeftMarginChange(Sender: TObject);
begin
  cmdOk.Enabled := PageSettingsValid();
end;

procedure TfrmPageDlg.txtRightMarginChange(Sender: TObject);
begin
  cmdOk.Enabled := PageSettingsValid();
end;

procedure TfrmPageDlg.txtBottomMarginChange(Sender: TObject);
begin
  cmdOk.Enabled := PageSettingsValid();
end;

procedure TfrmPageDlg.cmdOKClick(Sender: TObject);
begin
        doc.lLeftMargin:=DlgString2Twips(txtLeftMargin.Text);
        doc.lTopMargin:=DlgString2Twips(txtTopMargin.Text);
        doc.lRightMargin:=DlgString2Twips(txtRightMargin.Text);
        doc.lBottomMargin:=DlgString2Twips(txtBottomMargin.Text);
        doc.lWidth:=DlgString2Twips(txtPaperWidth.Text);
        doc.lHeight:=DlgString2Twips(txtPaperHeight.Text);
  frmMain.formresize(Sender);
  close;
end;

procedure TfrmPageDlg.Button2Click(Sender: TObject);
begin
  Close;
end;

end.
